@@ -1,9 +1,9 @@
 permut<-function(n)
 {
 	ind<-1:n
-	a<-sample(ind,n,replace="F")
+	a<-sample(ind,n)
 	asort <- sort(a)
-	b <- sample(asort,n,replace="F")
+	b <- sample(asort,n)
 	ind <- b
  	return(ind)
 }
